@@ -18,7 +18,6 @@
 #include <stdlib.h>
 #include <check.h>
 #include "../lib/utf8lite/src/utf8lite.h"
-#include "../src/text.h"
 #include "../src/sentscan.h"
 #include "testutil.h"
 
@@ -38,15 +37,15 @@ void teardown_scan(void)
 }
 
 
-void start(const struct corpus_text *text)
+void start(const struct utf8lite_text *text)
 {
 	corpus_sentscan_make(&scan, text, CORPUS_SENTSCAN_STRICT);
 }
 
 
-const struct corpus_text *next(void)
+const struct utf8lite_text *next(void)
 {
-	struct corpus_text *sent;
+	struct utf8lite_text *sent;
 	if (!corpus_sentscan_advance(&scan)) {
 		return NULL;
 	}
@@ -109,10 +108,10 @@ struct unitest {
 	unsigned line;
 	int is_ascii;
 
-	struct corpus_text text;
+	struct utf8lite_text text;
 	uint8_t buf[4096];
 
-	uint32_t code[256];
+	int32_t code[256];
 	int can_break_before[256];
 	uint8_t *code_end[256];
 	unsigned ncode;
@@ -184,9 +183,6 @@ void setup_unicode(void)
 			test->line = line;
 			test->is_ascii = is_ascii;
 			test->text.attr = (size_t)(dst - test->text.ptr);
-			if (!is_ascii) {
-				test->text.attr |= CORPUS_TEXT_UTF8_BIT;
-			}
 
 			if (ncode > 0) {
 				test->ncode = ncode;
@@ -227,11 +223,11 @@ void setup_unicode(void)
 			}
 
 			if (fscanf(file, "%x", &code)) {
-				test->code[ncode] = (uint32_t)code;
+				test->code[ncode] = (int32_t)code;
 				if (code > 0x7F) {
 					is_ascii = 0;
 				}
-				utf8lite_encode_utf8((uint32_t)code, &dst);
+				utf8lite_encode_utf8((int32_t)code, &dst);
 				test->code_end[ncode] = dst;
 				ncode++;
 			} else {
@@ -272,7 +268,7 @@ START_TEST(test_unicode)
 			ck_assert(corpus_sentscan_advance(&scan));
 			ck_assert(scan.current.ptr == test->break_begin[j]);
 			ck_assert(scan.current.ptr
-					+ CORPUS_TEXT_SIZE(&scan.current)
+					+ UTF8LITE_TEXT_SIZE(&scan.current)
 					== test->break_end[j]);
 		}
 		ck_assert(!corpus_sentscan_advance(&scan));
